@@ -1,12 +1,12 @@
 """utilities for fetching build dependencies."""
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 #  Copyright (C) PyZMQ Developers
 #  Distributed under the terms of the Modified BSD License.
 #
 #  This bundling code is largely adapted from pyzmq-static's get.sh by
 #  Brandon Craig-Rhodes, which is itself BSD licensed.
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 
 import os
@@ -28,9 +28,9 @@ from .msg import fatal, debug, info, warn
 
 pjoin = os.path.join
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Constants
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 bundled_version = (4, 3, 3)
 vs = '%i.%i.%i' % bundled_version
@@ -46,22 +46,25 @@ libzmq_checksum = (
 HERE = os.path.dirname(__file__)
 ROOT = os.path.dirname(HERE)
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # Utilities
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
+
 
 def untgz(archive):
     return archive.replace('.tar.gz', '')
 
+
 def localpath(*args):
     """construct an absolute path from a list relative to the root pyzmq directory"""
     plist = [ROOT] + list(args)
     return os.path.abspath(pjoin(*plist))
 
+
 def checksum_file(scheme, path):
     """Return the checksum (hex digest) of a file"""
     h = getattr(hashlib, scheme)()
-    
+
     with open(path, 'rb') as f:
         chunk = f.read(65535)
         while chunk:
@@ -69,11 +72,12 @@ def checksum_file(scheme, path):
             chunk = f.read(65535)
     return h.hexdigest()
 
+
 def fetch_archive(savedir, url, fname, checksum, force=False):
     """download an archive to a specific location"""
     dest = pjoin(savedir, fname)
     scheme, digest_ref = checksum.split(':')
-    
+
     if os.path.exists(dest) and not force:
         info("already have %s" % dest)
         digest = checksum_file(scheme, fname)
@@ -82,7 +86,7 @@ def fetch_archive(savedir, url, fname, checksum, force=False):
         else:
             warn("but checksum %s != %s, redownloading." % (digest, digest_ref))
             os.remove(fname)
-    
+
     info("fetching %s into %s" % (url, savedir))
     if not os.path.exists(savedir):
         os.makedirs(savedir)
@@ -91,13 +95,17 @@ def fetch_archive(savedir, url, fname, checksum, force=False):
         f.write(req.read())
     digest = checksum_file(scheme, dest)
     if digest != digest_ref:
-        fatal("%s %s mismatch:\nExpected: %s\nActual  : %s" % (
-            dest, scheme, digest_ref, digest))
+        fatal(
+            "%s %s mismatch:\nExpected: %s\nActual  : %s"
+            % (dest, scheme, digest_ref, digest)
+        )
     return dest
 
-#-----------------------------------------------------------------------------
+
+# -----------------------------------------------------------------------------
 # libzmq
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
+
 
 def fetch_libzmq(savedir):
     """download and extract libzmq"""
@@ -113,6 +121,7 @@ def fetch_libzmq(savedir):
     # remove version suffix:
     shutil.move(with_version, dest)
 
+
 def stage_platform_hpp(zmqroot):
     """stage platform.hpp into libzmq sources
 
@@ -162,39 +171,42 @@ def stage_platform_hpp(zmqroot):
 
 def copy_and_patch_libzmq(ZMQ, libzmq):
     """copy libzmq into source dir, and patch it if necessary.
-    
+
     This command is necessary prior to running a bdist on Linux or OS X.
     """
     if sys.platform.startswith('win'):
         return
     # copy libzmq into zmq for bdist
-    local = localpath('zmq',libzmq)
+    local = localpath('zmq', libzmq)
     if not ZMQ and not os.path.exists(local):
-        fatal("Please specify zmq prefix via `setup.py configure --zmq=/path/to/zmq` "
-        "or copy libzmq into zmq/ manually prior to running bdist.")
+        fatal(
+            "Please specify zmq prefix via `setup.py configure --zmq=/path/to/zmq` "
+            "or copy libzmq into zmq/ manually prior to running bdist."
+        )
     try:
         # resolve real file through symlinks
         lib = os.path.realpath(pjoin(ZMQ, 'lib', libzmq))
-        print ("copying %s -> %s"%(lib, local))
+        print("copying %s -> %s" % (lib, local))
         shutil.copy(lib, local)
     except Exception:
         if not os.path.exists(local):
-            fatal("Could not copy libzmq into zmq/, which is necessary for bdist. "
-            "Please specify zmq prefix via `setup.py configure --zmq=/path/to/zmq` "
-            "or copy libzmq into zmq/ manually.")
-    
+            fatal(
+                "Could not copy libzmq into zmq/, which is necessary for bdist. "
+                "Please specify zmq prefix via `setup.py configure --zmq=/path/to/zmq` "
+                "or copy libzmq into zmq/ manually."
+            )
+
     if sys.platform == 'darwin':
         # chmod u+w on the lib,
         # which can be user-read-only for some reason
         mode = os.stat(local).st_mode
         os.chmod(local, mode | stat.S_IWUSR)
         # patch install_name on darwin, instead of using rpath
-        cmd = ['install_name_tool', '-id', '@loader_path/../%s'%libzmq, local]
+        cmd = ['install_name_tool', '-id', '@loader_path/../%s' % libzmq, local]
         try:
-            p = Popen(cmd, stdout=PIPE,stderr=PIPE)
+            p = Popen(cmd, stdout=PIPE, stderr=PIPE)
         except OSError:
             fatal("install_name_tool not found, cannot patch libzmq for bundling.")
-        out,err = p.communicate()
+        out, err = p.communicate()
         if p.returncode:
-            fatal("Could not patch bundled libzmq install_name: %s"%err, p.returncode)
-        
+            fatal("Could not patch bundled libzmq install_name: %s" % err, p.returncode)
